pilas.actores.pausa

Package pilas :: Package actores :: Module pausa |
[hide private]
[frames] | no frames]

# Source Code for Module pilas.actores.pausa

     1  # -*- encoding: utf-8 -*-
     2  # Pilas engine - A video game framework.
     3  #
     4  # Copyright 2010 - Hugo Ruscitti
     5  # License: LGPLv3 (see http://www.gnu.org/licenses/lgpl.html)
     6  #
     7  # Website - http://www.pilas-engine.com.ar
     8
     9  from pilas.actores import Actor
    10
    11 -class Pausa(Actor):
    12      """Representa un ícono que se mostrará cuando el juego esté en pausa."""
    13
    14 -    def __init__(self, x=0, y=0):
    15          """Inicia el actor de pausa.
    16
    17          :param x: Posición horizontal del ícono.
    18          :param y: Posición vertical del ícono.
    19          """
    20          Actor.__init__(self, x=x, y=y)
    21          self.centro = ('centro', 'centro')
    22          self.imagen = "icono_pausa.png"
    23